@@ -4,7 +4,6 @@ import copy
 from collections import Counter
 from pathlib import Path
 from typing import Dict, List, Union, Tuple, Optional
-import warnings
 from datetime import datetime
 
 from geopandas import GeoDataFrame
@@ -46,24 +45,32 @@ class Workflow:
     ```
     """
 
-    def __init__(self, auth: Auth, project_id: str, workflow_id: str):
+    def __init__(
+        self,
+        auth: Auth,
+        project_id: str,
+        workflow_id: str,
+        workflow_info: Optional[dict] = None,
+    ):
         self.auth = auth
         self.project_id = project_id
         self.workflow_id = workflow_id
-        self._info = self.info
+        if workflow_info is not None:
+            self._info = workflow_info
+        else:
+            self._info = self.info
 
     def __repr__(self):
-        info = self.info
         return (
-            f"Workflow(name: {info['name']}, workflow_id: {self.workflow_id}, "
-            f"description: {info['description']}, createdAt: {info['createdAt']}, "
-            f"project_id: {self.project_id}, workflow_tasks: {self.workflow_tasks}"
+            f"Workflow(name: {self._info['name']}, workflow_id: {self.workflow_id}, "
+            f"description: {self._info['description']}, createdAt: {self._info['createdAt']}, "
+            f"project_id: {self.project_id}"
         )
 
     @property
     def info(self) -> dict:
         """
-        Gets the workflow metadata information.
+        Gets and updates the workflow metadata information.
         """
         url = (
             f"{self.auth._endpoint()}/projects/{self.project_id}/workflows/"
@@ -71,7 +78,7 @@ class Workflow:
         )
         response_json = self.auth._request(request_type="GET", url=url)
         self._info = response_json["data"]
-        return response_json["data"]
+        return self._info
 
     @property
     def workflow_tasks(self) -> Dict[str, str]:
@@ -332,7 +339,6 @@ class Workflow:
             Point,
         ] = None,
         geometry_operation: Optional[str] = None,
-        handle_multiple_features: str = "union",
         start_date: Optional[Union[str, datetime]] = None,
         end_date: Optional[Union[str, datetime]] = None,
         limit: Optional[int] = None,
@@ -361,13 +367,6 @@ class Workflow:
         Returns:
             Dictionary of constructed input parameters.
         """
-        message = (
-            "The use of `handle_multiple_features` will be deprecated in version 0.18.0, "
-            "to guarantee feature parity with the UP42 platform. The UP42 SDK from then on "
-            "will only handle single geometries!"
-        )
-        warnings.warn(message, DeprecationWarning, stacklevel=2)
-
         input_parameters = self._get_default_parameters()
         try:
             data_block_name = list(input_parameters.keys())[0]
@@ -406,7 +405,6 @@ class Workflow:
                 aoi_feature = fc_to_query_geometry(
                     fc=aoi_fc,
                     geometry_operation=geometry_operation,  # type: ignore
-                    squash_multiple_features=handle_multiple_features,
                 )
 
                 input_parameters[data_block_name][geometry_operation] = aoi_feature
